#region Copyright Syncfusion Inc. 2001 - 2006
//
//  Copyright Syncfusion Inc. 2001 - 2006. All rights reserved.
//
//  Use of this code is subject to the terms of our license.
//  A copy of the current license can be obtained at any time by e-mailing
//  licensing@syncfusion.com. Any infringement will be prosecuted under
//  applicable laws. 
//
#endregion

namespace TabbedMDI {

	using System;
	using System.ComponentModel;
	using System.Drawing;
	using System.Windows.Forms;
	using Syncfusion.Windows.Forms;
	using Microsoft.Win32;
	using Syncfusion.Windows.Forms.Tools;
	using Syncfusion.Windows.Forms.Tools.XPMenus;
	using Syncfusion.Runtime.Serialization;

	using System.Diagnostics;
	using System.Runtime.InteropServices;

    public class MainForm : System.Windows.Forms.Form 
	{
		# region Declaration
		private System.ComponentModel.IContainer components;
        private System.Windows.Forms.MainMenu mainMenu;
        protected System.Windows.Forms.StatusBar statusBar1;
		private TabbedMDIManager tabbedMDIManager;
		private System.Windows.Forms.MenuItem menuItem2;
		private System.Windows.Forms.MenuItem menuItem3;
		private System.Windows.Forms.MenuItem menuItem7;
		private System.Windows.Forms.MenuItem addDoc1;
		private System.Windows.Forms.MenuItem menuItem5;
		private System.Windows.Forms.MenuItem menuItem6;
		private System.Windows.Forms.MenuItem parseChildren;
		private System.Windows.Forms.MenuItem toggleAlign;
		private System.Windows.Forms.MenuItem exitMenu;
		private MenuItem miWindow;
		private System.Windows.Forms.MenuItem menuItem1;
		private System.Windows.Forms.MenuItem menuItem4;
		private System.Windows.Forms.ImageList imageList1;
		private System.Windows.Forms.MenuItem menuItem8;
		private System.Windows.Forms.MenuItem menuItem9;
		private System.Windows.Forms.MenuItem menuItem10;
		private System.Windows.Forms.MenuItem menuItem11;
		private System.Windows.Forms.MenuItem menuItem12;
		private System.Windows.Forms.MenuItem menuItem13;
		private System.Windows.Forms.MenuItem menuItem14;
		private System.Windows.Forms.MenuItem menuItem15;
		private System.Windows.Forms.MenuItem menuItem16;
		private System.Windows.Forms.MenuItem menuItem17;
		private System.Windows.Forms.MenuItem menuItem18;
		private System.Windows.Forms.MenuItem menuItem19;
		private System.Windows.Forms.MenuItem menuItem20;
		private System.Windows.Forms.MenuItem menuItem21;
		private System.Windows.Forms.Panel panel1;
		private System.Windows.Forms.CheckBox checkBox1;
		private System.Windows.Forms.CheckBox checkBox2;
		private System.Windows.Forms.CheckBox checkBox4;
		private System.Windows.Forms.CheckBox checkBox5;
		private System.Windows.Forms.GroupBox groupBox1;
		private System.Windows.Forms.GroupBox groupBox2;
		private System.Windows.Forms.CheckBox checkBox6;
		private System.Windows.Forms.CheckBox checkBox7;
		private System.Windows.Forms.CheckBox checkBox8;
		private System.Windows.Forms.MenuItem menuItem22;
		private System.Windows.Forms.MenuItem menuItem23;
		private System.Windows.Forms.MenuItem menuItem24;
		private System.Windows.Forms.TabControl tabControl1;
		private System.Windows.Forms.TabPage tabPage1;
		private System.Windows.Forms.TabPage tabPage2;
		private System.Windows.Forms.PropertyGrid propertyGrid1;
		private System.Windows.Forms.Splitter splitter1;
		private System.Windows.Forms.CheckBox checkBox3;
		private bool tabWindowsOn = false;
		#endregion

        public MainForm() 
		{
            InitializeComponent();

			tabbedMDIManager = new TabbedMDIManager();
			this.propertyGrid1.SelectedObject = (object)this.tabbedMDIManager;
			this.tabbedMDIManager.TabControlAdded += new TabbedMDITabControlEventHandler(tabbedMDIManager_TabControlAdded);
			this.tabbedMDIManager.BeforeDropDownPopup += new DropDownPopupEventHandler(tabbedMDIManager_BeforePopup);
			
			#region Dynamically created menus
			this.miWindow = mainMenu.MenuItems.Add("Window");
			miWindow.MergeOrder = 6;
			miWindow.MenuItems.Add("Cascade", new System.EventHandler(this.WindowCascade_Clicked));
			miWindow.MenuItems.Add("Tile Horizontal", new System.EventHandler(this.WindowTileH_Clicked));
			miWindow.MenuItems.Add("Tile Vertical", new System.EventHandler(this.WindowTileV_Clicked));
			miWindow.MenuItems.Add("MDI Tabbed", new System.EventHandler(this.TabbedWindows_Clicked));

			// Let the TabbedMDIManager insert the Mdi Child windows list
			this.tabbedMDIManager.MdiListMenuItem = miWindow;
			#endregion
			
			#region Append menus to the standard mdi tab context menu
			ParentBarItem contextMenuItem = new ParentBarItem();
			contextMenuItem.Style = VisualStyle.Office2003;

			BarItem newDocItem = new BarItem();
			newDocItem.ImageList = this.imageList1;
			newDocItem.ImageIndex = 5;
			newDocItem.Click += new System.EventHandler(this.addDoc1_Click);
			newDocItem.Text = "Custom Item: Insert New Doc";
			newDocItem.MergeOrder = 30;
			contextMenuItem.Items.Add(newDocItem);

			BarItem exitItem = new BarItem();
			exitItem.ImageList = this.imageList1;
			exitItem.ImageIndex = 2;
			exitItem.Click += new System.EventHandler(this.FileExit_Clicked);
			exitItem.Text = "CustomItem: Exit";
			exitItem.MergeOrder = 30;
			contextMenuItem.Items.Add(exitItem);

			contextMenuItem.BeginGroupAt(newDocItem);

            //////////////mio

            tabbedMDIManager.ContextMenuItem.Items.Dispose();
            //////////////mio

			// Items in this ParentBarItem will be merged with the standard context menu ParentBarItem of the mdi tab.
			tabbedMDIManager.ContextMenuItem = contextMenuItem;
			#endregion
        }

        # region Handlers
        // Convenient way to toggle TabbedMDI mode.
        internal bool TabbedMDIOn
		{
			get	{	return this.tabWindowsOn;	}
			set
			{
				if(!(this.tabWindowsOn == value))
				{
					this.tabWindowsOn = value;

					if(this.tabWindowsOn)
					{
						this.tabbedMDIManager.AttachToMdiContainer(this);
					}
					else
					{
						this.tabbedMDIManager.DetachFromMdiContainer(this, false); // false to not invoke the Cascade mode after detaching.
					}
				}
			}
		}


		internal TabbedMDIManager TabbedMDIManager
		{
			get{return this.tabbedMDIManager;}
		}


        //Add a document 
        private void AddDocument(Form doc) {
            doc.MdiParent = this;
            doc.Show();
        }


		private void MainForm_Load(object sender, System.EventArgs e)
		{
			// Add 4 documents
			this.addDoc1_Click(this, EventArgs.Empty);
			this.addDoc1_Click(this, EventArgs.Empty);
			this.addDoc1_Click(this, EventArgs.Empty);
			this.addDoc1_Click(this, EventArgs.Empty);

			// Turn on MDI Tabbed Documents mode.
			// Call this after loading the mdi children to restore their previous state.
			this.TabbedMDIOn = true;

			this.tabbedMDIManager.CloseOnMiddleButtonClick = true;
		}


		private int document1Count = 0 ;

		internal void addDoc1_Click(object sender, System.EventArgs e)
		{
			
			document1Count++ ;
			Document1 doc = new Document1("Document " + document1Count.ToString());
			AddDocument(doc);
			this.tabbedMDIManager.SetTooltip(doc, "Tooltip for " + doc.Text);
		}


        //Window->Cascade Menu item handler
        protected internal void WindowCascade_Clicked(object sender, System.EventArgs e) {
			this.TabbedMDIOn = false;
            this.LayoutMdi(MdiLayout.Cascade);   
        }
	

        //Window->Tile Horizontally Menu item handler
        protected void WindowTileH_Clicked(object sender, System.EventArgs e) {
			this.TabbedMDIOn = false;
            this.LayoutMdi(MdiLayout.TileHorizontal);
        }


        //Window->Tile Vertically Menu item handler
        protected void WindowTileV_Clicked(object sender, System.EventArgs e) {
			this.TabbedMDIOn = false;
            this.LayoutMdi(MdiLayout.TileVertical);
        }


		protected internal void TabbedWindows_Clicked(object sender, System.EventArgs e)
		{
			this.TabbedMDIOn = true;
		}


		//File->Exit Menu item handler
		protected void FileExit_Clicked(object sender, System.EventArgs e) 
		{
			this.Close();
		}


		//One of the MDI Child windows has been activated
		protected void MDIChildActivated(object sender, System.EventArgs e) 
		{
			if (this.ActiveMdiChild == null) 
			{
				statusBar1.Text = "";
			} 
			else 
			{
				statusBar1.Text = this.ActiveMdiChild.Text;
			}
		}

		#endregion

        /// <summary>
        ///    Clean up any resources being used.
        /// </summary>
        protected override void Dispose(bool disposing) 
        {
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
				this.tabbedMDIManager.Dispose();
			}
			base.Dispose( disposing );
        }

        /// <summary>
        ///    Required method for Designer support - do not modify
        ///    the contents of this method with the code editor.
        /// </summary>
        /// 
        protected void InitializeComponent()
        {
			this.components = new System.ComponentModel.Container();
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(MainForm));
			this.mainMenu = new System.Windows.Forms.MainMenu();
			this.menuItem2 = new System.Windows.Forms.MenuItem();
			this.menuItem3 = new System.Windows.Forms.MenuItem();
			this.addDoc1 = new System.Windows.Forms.MenuItem();
			this.menuItem7 = new System.Windows.Forms.MenuItem();
			this.exitMenu = new System.Windows.Forms.MenuItem();
			this.menuItem5 = new System.Windows.Forms.MenuItem();
			this.toggleAlign = new System.Windows.Forms.MenuItem();
			this.menuItem6 = new System.Windows.Forms.MenuItem();
			this.parseChildren = new System.Windows.Forms.MenuItem();
			this.menuItem8 = new System.Windows.Forms.MenuItem();
			this.menuItem9 = new System.Windows.Forms.MenuItem();
			this.menuItem10 = new System.Windows.Forms.MenuItem();
			this.menuItem11 = new System.Windows.Forms.MenuItem();
			this.menuItem12 = new System.Windows.Forms.MenuItem();
			this.menuItem13 = new System.Windows.Forms.MenuItem();
			this.menuItem14 = new System.Windows.Forms.MenuItem();
			this.menuItem15 = new System.Windows.Forms.MenuItem();
			this.menuItem16 = new System.Windows.Forms.MenuItem();
			this.menuItem24 = new System.Windows.Forms.MenuItem();
			this.menuItem22 = new System.Windows.Forms.MenuItem();
			this.menuItem23 = new System.Windows.Forms.MenuItem();
			this.menuItem17 = new System.Windows.Forms.MenuItem();
			this.menuItem18 = new System.Windows.Forms.MenuItem();
			this.menuItem19 = new System.Windows.Forms.MenuItem();
			this.menuItem20 = new System.Windows.Forms.MenuItem();
			this.menuItem21 = new System.Windows.Forms.MenuItem();
			this.menuItem1 = new System.Windows.Forms.MenuItem();
			this.menuItem4 = new System.Windows.Forms.MenuItem();
			this.statusBar1 = new System.Windows.Forms.StatusBar();
			this.imageList1 = new System.Windows.Forms.ImageList(this.components);
			this.panel1 = new System.Windows.Forms.Panel();
			this.checkBox2 = new System.Windows.Forms.CheckBox();
			this.checkBox1 = new System.Windows.Forms.CheckBox();
			this.groupBox1 = new System.Windows.Forms.GroupBox();
			this.checkBox8 = new System.Windows.Forms.CheckBox();
			this.checkBox7 = new System.Windows.Forms.CheckBox();
			this.checkBox6 = new System.Windows.Forms.CheckBox();
			this.groupBox2 = new System.Windows.Forms.GroupBox();
			this.checkBox4 = new System.Windows.Forms.CheckBox();
			this.checkBox5 = new System.Windows.Forms.CheckBox();
			this.tabControl1 = new System.Windows.Forms.TabControl();
			this.tabPage1 = new System.Windows.Forms.TabPage();
			this.tabPage2 = new System.Windows.Forms.TabPage();
			this.propertyGrid1 = new System.Windows.Forms.PropertyGrid();
			this.splitter1 = new System.Windows.Forms.Splitter();
			this.checkBox3 = new System.Windows.Forms.CheckBox();
			this.panel1.SuspendLayout();
			this.groupBox1.SuspendLayout();
			this.groupBox2.SuspendLayout();
			this.tabControl1.SuspendLayout();
			this.tabPage1.SuspendLayout();
			this.tabPage2.SuspendLayout();
			this.SuspendLayout();
			// 
			// mainMenu
			// 
			this.mainMenu.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																					 this.menuItem2,
																					 this.menuItem5,
																					 this.menuItem8,
																					 this.menuItem17,
																					 this.menuItem1});
			// 
			// menuItem2
			// 
			this.menuItem2.Index = 0;
			this.menuItem2.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																					  this.menuItem3,
																					  this.menuItem7,
																					  this.exitMenu});
			this.menuItem2.Text = "&File";
			// 
			// menuItem3
			// 
			this.menuItem3.Index = 0;
			this.menuItem3.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																					  this.addDoc1});
			this.menuItem3.Text = "&New";
			// 
			// addDoc1
			// 
			this.addDoc1.Index = 0;
			this.addDoc1.MergeOrder = 20;
			this.addDoc1.Shortcut = System.Windows.Forms.Shortcut.CtrlD;
			this.addDoc1.Text = "&Document";
			this.addDoc1.Click += new System.EventHandler(this.addDoc1_Click);
			// 
			// menuItem7
			// 
			this.menuItem7.Index = 1;
			this.menuItem7.Text = "-";
			// 
			// exitMenu
			// 
			this.exitMenu.Index = 2;
			this.exitMenu.MergeOrder = 20;
			this.exitMenu.Text = "E&xit";
			this.exitMenu.Click += new System.EventHandler(this.FileExit_Clicked);
			// 
			// menuItem5
			// 
			this.menuItem5.Index = 1;
			this.menuItem5.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																					  this.toggleAlign,
																					  this.menuItem6,
																					  this.parseChildren});
			this.menuItem5.MergeOrder = 1;
			this.menuItem5.Text = "&MDITabs";
			// 
			// toggleAlign
			// 
			this.toggleAlign.Index = 0;
			this.toggleAlign.Text = "Alignment Toggle";
			this.toggleAlign.Click += new System.EventHandler(this.toggleAlign_Click);
			// 
			// menuItem6
			// 
			this.menuItem6.Index = 1;
			this.menuItem6.Text = "-";
			// 
			// parseChildren
			// 
			this.parseChildren.Index = 2;
			this.parseChildren.Text = "Parse Children";
			this.parseChildren.Click += new System.EventHandler(this.parseChildren_Click);
			// 
			// menuItem8
			// 
			this.menuItem8.Index = 2;
			this.menuItem8.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																					  this.menuItem9,
																					  this.menuItem10,
																					  this.menuItem11,
																					  this.menuItem12,
																					  this.menuItem13,
																					  this.menuItem14,
																					  this.menuItem15,
																					  this.menuItem16,
																					  this.menuItem24,
																					  this.menuItem22,
																					  this.menuItem23});
			this.menuItem8.MergeOrder = 4;
			this.menuItem8.Text = "&Visual Styles";
			// 
			// menuItem9
			// 
			this.menuItem9.Checked = true;
			this.menuItem9.Index = 0;
			this.menuItem9.Text = "2D";
			this.menuItem9.Click += new System.EventHandler(this.menu_Click);
			// 
			// menuItem10
			// 
			this.menuItem10.Index = 1;
			this.menuItem10.Text = "3D";
			this.menuItem10.Click += new System.EventHandler(this.menu_Click);
			// 
			// menuItem11
			// 
			this.menuItem11.Index = 2;
			this.menuItem11.Text = "Workbook Mode";
			this.menuItem11.Click += new System.EventHandler(this.menu_Click);
			// 
			// menuItem12
			// 
			this.menuItem12.Index = 3;
			this.menuItem12.Text = "OneNoteStyle";
			this.menuItem12.Click += new System.EventHandler(this.menu_Click);
			// 
			// menuItem13
			// 
			this.menuItem13.Index = 4;
			this.menuItem13.Text = "OneNoteStyleFlatTabs";
			this.menuItem13.Click += new System.EventHandler(this.menu_Click);
			// 
			// menuItem14
			// 
			this.menuItem14.Index = 5;
			this.menuItem14.Text = "Office2003";
			this.menuItem14.Click += new System.EventHandler(this.menu_Click);
			// 
			// menuItem15
			// 
			this.menuItem15.Index = 6;
			this.menuItem15.Text = "Whidbey";
			this.menuItem15.Click += new System.EventHandler(this.menu_Click);
			// 
			// menuItem16
			// 
			this.menuItem16.Index = 7;
			this.menuItem16.Text = "DockingWhidbey";
			this.menuItem16.Click += new System.EventHandler(this.menu_Click);
			// 
			// menuItem24
			// 
			this.menuItem24.Index = 8;
			this.menuItem24.Text = "DockingWhidbeyBeta";
			this.menuItem24.Click += new System.EventHandler(this.menu_Click);
			// 
			// menuItem22
			// 
			this.menuItem22.Index = 9;
			this.menuItem22.Text = "IE7";
			this.menuItem22.Click += new System.EventHandler(this.menu_Click);
			// 
			// menuItem23
			// 
			this.menuItem23.Index = 10;
			this.menuItem23.Text = "Office2007";
			this.menuItem23.Click += new System.EventHandler(this.menu_Click);
			// 
			// menuItem17
			// 
			this.menuItem17.Index = 3;
			this.menuItem17.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																					   this.menuItem18,
																					   this.menuItem19,
																					   this.menuItem20,
																					   this.menuItem21});
			this.menuItem17.MergeOrder = 5;
			this.menuItem17.Text = "&Alignment";
			// 
			// menuItem18
			// 
			this.menuItem18.Checked = true;
			this.menuItem18.Index = 0;
			this.menuItem18.Text = "Top";
			this.menuItem18.Click += new System.EventHandler(this.menu_align_click);
			// 
			// menuItem19
			// 
			this.menuItem19.Index = 1;
			this.menuItem19.Text = "Bottom";
			this.menuItem19.Click += new System.EventHandler(this.menu_align_click);
			// 
			// menuItem20
			// 
			this.menuItem20.Index = 2;
			this.menuItem20.Text = "Left";
			this.menuItem20.Click += new System.EventHandler(this.menu_align_click);
			// 
			// menuItem21
			// 
			this.menuItem21.Index = 3;
			this.menuItem21.Text = "Right";
			this.menuItem21.Click += new System.EventHandler(this.menu_align_click);
			// 
			// menuItem1
			// 
			this.menuItem1.Index = 4;
			this.menuItem1.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																					  this.menuItem4});
			this.menuItem1.MergeOrder = 7;
			this.menuItem1.Text = "&Help";
			// 
			// menuItem4
			// 
			this.menuItem4.Index = 0;
			this.menuItem4.Text = "&About Syncfusion";
			this.menuItem4.Click += new System.EventHandler(this.menuItem4_Click);
			// 
			// statusBar1
			// 
			this.statusBar1.Location = new System.Drawing.Point(0, 377);
			this.statusBar1.Name = "statusBar1";
			this.statusBar1.Size = new System.Drawing.Size(632, 24);
			this.statusBar1.TabIndex = 1;
			// 
			// imageList1
			// 
			this.imageList1.ColorDepth = System.Windows.Forms.ColorDepth.Depth32Bit;
			this.imageList1.ImageSize = new System.Drawing.Size(16, 16);
			this.imageList1.ImageStream = ((System.Windows.Forms.ImageListStreamer)(resources.GetObject("imageList1.ImageStream")));
			this.imageList1.TransparentColor = System.Drawing.Color.Transparent;
			// 
			// panel1
			// 
			this.panel1.BackColor = System.Drawing.Color.FromArgb(((System.Byte)(118)), ((System.Byte)(126)), ((System.Byte)(165)));
			this.panel1.Controls.AddRange(new System.Windows.Forms.Control[] {
																				 this.checkBox2,
																				 this.checkBox1,
																				 this.groupBox1,
																				 this.groupBox2});
			this.panel1.Dock = System.Windows.Forms.DockStyle.Fill;
			this.panel1.Name = "panel1";
			this.panel1.Size = new System.Drawing.Size(184, 348);
			this.panel1.TabIndex = 8;
			// 
			// checkBox2
			// 
			this.checkBox2.ForeColor = System.Drawing.Color.White;
			this.checkBox2.Location = new System.Drawing.Point(16, 48);
			this.checkBox2.Name = "checkBox2";
			this.checkBox2.Size = new System.Drawing.Size(144, 24);
			this.checkBox2.TabIndex = 11;
			this.checkBox2.Text = "Close Button for Tabs";
			this.checkBox2.CheckedChanged += new System.EventHandler(this.checkBox2_CheckedChanged);
			// 
			// checkBox1
			// 
			this.checkBox1.BackColor = System.Drawing.Color.FromArgb(((System.Byte)(118)), ((System.Byte)(126)), ((System.Byte)(165)));
			this.checkBox1.ForeColor = System.Drawing.Color.White;
			this.checkBox1.Location = new System.Drawing.Point(16, 24);
			this.checkBox1.Name = "checkBox1";
			this.checkBox1.Size = new System.Drawing.Size(136, 24);
			this.checkBox1.TabIndex = 10;
			this.checkBox1.Text = "DropDownList";
			this.checkBox1.CheckedChanged += new System.EventHandler(this.checkBox1_CheckedChanged);
			// 
			// groupBox1
			// 
			this.groupBox1.BackColor = System.Drawing.Color.FromArgb(((System.Byte)(118)), ((System.Byte)(126)), ((System.Byte)(165)));
			this.groupBox1.Controls.AddRange(new System.Windows.Forms.Control[] {
																					this.checkBox3,
																					this.checkBox8,
																					this.checkBox7,
																					this.checkBox6});
			this.groupBox1.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.groupBox1.ForeColor = System.Drawing.Color.White;
			this.groupBox1.Location = new System.Drawing.Point(8, 8);
			this.groupBox1.Name = "groupBox1";
			this.groupBox1.Size = new System.Drawing.Size(168, 208);
			this.groupBox1.TabIndex = 16;
			this.groupBox1.TabStop = false;
			this.groupBox1.Text = "MDI Features";
			// 
			// checkBox8
			// 
			this.checkBox8.Checked = true;
			this.checkBox8.CheckState = System.Windows.Forms.CheckState.Checked;
			this.checkBox8.Location = new System.Drawing.Point(8, 136);
			this.checkBox8.Name = "checkBox8";
			this.checkBox8.Size = new System.Drawing.Size(144, 32);
			this.checkBox8.TabIndex = 15;
			this.checkBox8.Text = "Show/Hide Close Button";
			this.checkBox8.CheckedChanged += new System.EventHandler(this.checkBox8_CheckedChanged);
			// 
			// checkBox7
			// 
			this.checkBox7.Checked = true;
			this.checkBox7.CheckState = System.Windows.Forms.CheckState.Checked;
			this.checkBox7.Location = new System.Drawing.Point(8, 104);
			this.checkBox7.Name = "checkBox7";
			this.checkBox7.Size = new System.Drawing.Size(136, 24);
			this.checkBox7.TabIndex = 14;
			this.checkBox7.Text = "MDI TabPanel Visible";
			this.checkBox7.CheckedChanged += new System.EventHandler(this.checkBox7_CheckedChanged);
			// 
			// checkBox6
			// 
			this.checkBox6.Checked = true;
			this.checkBox6.CheckState = System.Windows.Forms.CheckState.Checked;
			this.checkBox6.Location = new System.Drawing.Point(8, 72);
			this.checkBox6.Name = "checkBox6";
			this.checkBox6.Size = new System.Drawing.Size(120, 24);
			this.checkBox6.TabIndex = 13;
			this.checkBox6.Text = "Use Icon in Tabs";
			this.checkBox6.CheckedChanged += new System.EventHandler(this.checkBox6_CheckedChanged);
			// 
			// groupBox2
			// 
			this.groupBox2.Controls.AddRange(new System.Windows.Forms.Control[] {
																					this.checkBox4,
																					this.checkBox5});
			this.groupBox2.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.groupBox2.ForeColor = System.Drawing.Color.White;
			this.groupBox2.Location = new System.Drawing.Point(8, 232);
			this.groupBox2.Name = "groupBox2";
			this.groupBox2.Size = new System.Drawing.Size(168, 88);
			this.groupBox2.TabIndex = 9;
			this.groupBox2.TabStop = false;
			this.groupBox2.Text = "Cancellable Events";
			// 
			// checkBox4
			// 
			this.checkBox4.Location = new System.Drawing.Point(8, 24);
			this.checkBox4.Name = "checkBox4";
			this.checkBox4.Size = new System.Drawing.Size(144, 24);
			this.checkBox4.TabIndex = 13;
			this.checkBox4.Text = "Hide Tab ContextMenu";
			this.checkBox4.CheckedChanged += new System.EventHandler(this.checkBox4_CheckedChanged);
			// 
			// checkBox5
			// 
			this.checkBox5.Location = new System.Drawing.Point(8, 48);
			this.checkBox5.Name = "checkBox5";
			this.checkBox5.Size = new System.Drawing.Size(144, 32);
			this.checkBox5.TabIndex = 14;
			this.checkBox5.Text = "Hide DropDownList Menu";
			this.checkBox5.CheckedChanged += new System.EventHandler(this.checkBox5_CheckedChanged);
			// 
			// tabControl1
			// 
			this.tabControl1.Appearance = System.Windows.Forms.TabAppearance.FlatButtons;
			this.tabControl1.Controls.AddRange(new System.Windows.Forms.Control[] {
																					  this.tabPage1,
																					  this.tabPage2});
			this.tabControl1.Dock = System.Windows.Forms.DockStyle.Right;
			this.tabControl1.Location = new System.Drawing.Point(440, 0);
			this.tabControl1.Name = "tabControl1";
			this.tabControl1.SelectedIndex = 0;
			this.tabControl1.Size = new System.Drawing.Size(192, 377);
			this.tabControl1.TabIndex = 10;
			// 
			// tabPage1
			// 
			this.tabPage1.Controls.AddRange(new System.Windows.Forms.Control[] {
																				   this.panel1});
			this.tabPage1.Location = new System.Drawing.Point(4, 25);
			this.tabPage1.Name = "tabPage1";
			this.tabPage1.Size = new System.Drawing.Size(184, 348);
			this.tabPage1.TabIndex = 0;
			this.tabPage1.Text = "Features";
			// 
			// tabPage2
			// 
			this.tabPage2.Controls.AddRange(new System.Windows.Forms.Control[] {
																				   this.propertyGrid1});
			this.tabPage2.Location = new System.Drawing.Point(4, 25);
			this.tabPage2.Name = "tabPage2";
			this.tabPage2.Size = new System.Drawing.Size(184, 316);
			this.tabPage2.TabIndex = 1;
			this.tabPage2.Text = "Property Grid";
			// 
			// propertyGrid1
			// 
			this.propertyGrid1.CommandsVisibleIfAvailable = true;
			this.propertyGrid1.Dock = System.Windows.Forms.DockStyle.Fill;
			this.propertyGrid1.HelpVisible = false;
			this.propertyGrid1.LargeButtons = false;
			this.propertyGrid1.LineColor = System.Drawing.SystemColors.ScrollBar;
			this.propertyGrid1.Name = "propertyGrid1";
			this.propertyGrid1.Size = new System.Drawing.Size(184, 316);
			this.propertyGrid1.TabIndex = 0;
			this.propertyGrid1.Text = "propertyGrid1";
			this.propertyGrid1.ToolbarVisible = false;
			this.propertyGrid1.ViewBackColor = System.Drawing.SystemColors.Window;
			this.propertyGrid1.ViewForeColor = System.Drawing.SystemColors.WindowText;
			// 
			// splitter1
			// 
			this.splitter1.Dock = System.Windows.Forms.DockStyle.Right;
			this.splitter1.Location = new System.Drawing.Point(437, 0);
			this.splitter1.Name = "splitter1";
			this.splitter1.Size = new System.Drawing.Size(3, 377);
			this.splitter1.TabIndex = 11;
			this.splitter1.TabStop = false;
			// 
			// checkBox3
			// 
			this.checkBox3.Checked = true;
			this.checkBox3.CheckState = System.Windows.Forms.CheckState.Checked;
			this.checkBox3.ForeColor = System.Drawing.Color.White;
			this.checkBox3.Location = new System.Drawing.Point(8, 168);
			this.checkBox3.Name = "checkBox3";
			this.checkBox3.Size = new System.Drawing.Size(144, 32);
			this.checkBox3.TabIndex = 16;
			this.checkBox3.Text = "Close on Mouse Middle Click";
			this.checkBox3.CheckedChanged += new System.EventHandler(this.checkBox3_CheckedChanged);
			// 
			// MainForm
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(632, 401);
			this.Controls.AddRange(new System.Windows.Forms.Control[] {
																		  this.splitter1,
																		  this.tabControl1,
																		  this.statusBar1});
			this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
			this.IsMdiContainer = true;
			this.Menu = this.mainMenu;
			this.Name = "MainForm";
			this.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen;
			this.Text = "Tabbed MDI Demo (Syncfusion Inc.)";
			this.MdiChildActivate += new System.EventHandler(this.MDIChildActivated);
			this.Load += new System.EventHandler(this.MainForm_Load);
			this.panel1.ResumeLayout(false);
			this.groupBox1.ResumeLayout(false);
			this.groupBox2.ResumeLayout(false);
			this.tabControl1.ResumeLayout(false);
			this.tabPage1.ResumeLayout(false);
			this.tabPage2.ResumeLayout(false);
			this.ResumeLayout(false);

		}


		#region DLL Imports
		[DllImport("user32.dll", CharSet=CharSet.Auto)]
		extern public static bool SetForegroundWindow(IntPtr hwnd);
		#endregion

		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		public static void Main() 
		{
			// Modify this version, whenever changes are made such that the persisted state cannot be loaded anymore.
			string curVersion = "1.0";
			ValidatePersistedStateVersion(curVersion);
			StoreVersionInfo(curVersion);

			MainForm mainForm = new MainForm();

			bool bRunning = false;
			foreach ( Process p in Process.GetProcesses(System.Environment.MachineName) )
			{
				if( p.MainWindowHandle != IntPtr.Zero)
				{
					// Process name gets truncated!
					if(p.ProcessName == "TabbedMDI")
					{
						bRunning = true;
						MessageBox.Show("Activating the already open instance of TabbedMDI.exe.");
						SetForegroundWindow(p.MainWindowHandle);
						break;
					}
				}
			}
			if(!bRunning)
			{
				Application.Run(mainForm);
			}
		}


		#region VERSIONING
		static string VersionTag = "AppVersion";
		static void ValidatePersistedStateVersion(string curVersion)
		{
			// Versioning
			AppStateSerializer serializer = AppStateSerializer.GetSingleton();
			object objectOut = serializer.DeserializeObject(VersionTag);
			if(objectOut != null)
			{
				string version = (string)objectOut;
				version = version.ToLower();

				curVersion = curVersion.ToLower();

				// Persisted info is not the current version, lets lose it.
				if(version != curVersion)
					serializer.FlushSerializer();
			}
		}
		// Store the current version, so that we can validate it the next time.
		static void StoreVersionInfo(string curVersion)
		{
			AppStateSerializer serializer = AppStateSerializer.GetSingleton();
			serializer.SerializeObject(VersionTag, curVersion, true);
		}
		#endregion VERSIONING

		#region AboutForm_Logic
		DemoCommon.AboutForm aboutForm = null;
		private void menuItem4_Click(object sender, System.EventArgs e)
		{
			aboutForm = new DemoCommon.AboutForm(AppDomain.CurrentDomain.GetAssemblies());
			aboutForm.ShowDialog();
		}
		private void AboutFormCloseBtnClicked(object sender, EventArgs e)
		{
			aboutForm.Close();
		}
		#endregion AboutForm_Logic

		#region VisualStyles
		public void MenuCheckRemove(System.Windows.Forms.MenuItem Item)
		{
			foreach (MenuItem menuItem in this.menuItem8.MenuItems)
			{
				if (menuItem != Item)
				{
					((MenuItem)menuItem).Checked = false;

				}
				else
					((MenuItem)menuItem).Checked = true;
			}
		}

		private void menu_Click(object sender, System.EventArgs e)
		{
			this.MenuCheckRemove((MenuItem)sender);
			
			if (this.menuItem16.Checked == true)
				this.tabbedMDIManager.TabStyle = typeof(Syncfusion.Windows.Forms.Tools.TabRendererDockingWhidbey);
			else if (this.menuItem15.Checked == true)
				this.tabbedMDIManager.TabStyle = typeof(Syncfusion.Windows.Forms.Tools.TabRendererWhidbey);
			else if (this.menuItem9.Checked == true)
				this.tabbedMDIManager.TabStyle = typeof(Syncfusion.Windows.Forms.Tools.TabRenderer2D);
			else if (this.menuItem10.Checked == true)
				this.tabbedMDIManager.TabStyle = typeof(Syncfusion.Windows.Forms.Tools.TabRenderer3D);
			else if (this.menuItem14.Checked == true)
				this.tabbedMDIManager.TabStyle = typeof(Syncfusion.Windows.Forms.Tools.TabRendererOffice2003);
			else if (this.menuItem11.Checked == true)
				this.tabbedMDIManager.TabStyle = typeof(Syncfusion.Windows.Forms.Tools.TabRendererWorkbookMode);
			else if (this.menuItem12.Checked == true)
				this.tabbedMDIManager.TabStyle = typeof(Syncfusion.Windows.Forms.Tools.OneNoteStyleRenderer);
			else if (this.menuItem13.Checked == true)
				this.tabbedMDIManager.TabStyle = typeof(Syncfusion.Windows.Forms.Tools.OneNoteStyleFlatTabsRenderer);
			else if (this.menuItem22.Checked == true)
				this.tabbedMDIManager.TabStyle = typeof(Syncfusion.Windows.Forms.Tools.TabRendererIE7);
			else if (this.menuItem23.Checked == true)
				this.tabbedMDIManager.TabStyle = typeof(Syncfusion.Windows.Forms.Tools.TabRendererOffice2007);
			else if (this.menuItem24.Checked == true)
				this.tabbedMDIManager.TabStyle = typeof(Syncfusion.Windows.Forms.Tools.TabRendererDockingWhidbeyBeta);

		}

		#endregion

		#region Alignment
		private void menu_align_click(object sender, System.EventArgs e)
		{
			// User can uncomment the LockHostFormUpdate and UnLockHostFormUpdate methods 
			// to prevent the flickering when changing the Alignments, since the alignment 
			// can be changed only in TabControlAdded event, which gets fired MDITabPanel gets created.
			// NOTE: Since, these methods stops the window painting, it may cause certain painting issues.

			//	this.tabbedMDIManager.LockHostFormUpdate();
			this.TabbedMDIOn = false;
			this.MenuCheckRemove_Align((MenuItem)sender);
			this.TabbedMDIOn = true;
			//	this.tabbedMDIManager.UnlockHostFormUpdate();
		}

		public void MenuCheckRemove_Align(System.Windows.Forms.MenuItem Item)
		{
			foreach (MenuItem menuItem in this.menuItem17.MenuItems)
			{
				if (menuItem != Item)
				{
					((MenuItem)menuItem).Checked = false;

				}
				else
					((MenuItem)menuItem).Checked = true;
				
			}
		}

		#endregion
	
		#region Features
		private void checkBox1_CheckedChanged(object sender, System.EventArgs e)
		{
			this.tabbedMDIManager.DropDownButtonVisible = !this.tabbedMDIManager.DropDownButtonVisible;
		}

		private void checkBox2_CheckedChanged(object sender, System.EventArgs e)
		{
			this.tabbedMDIManager.ShowCloseButton = !this.tabbedMDIManager.ShowCloseButton;
		}

		private void checkBox4_CheckedChanged(object sender, System.EventArgs e)
		{
			this.tabbedMDIManager.ContextMenuItem.BeforePopup += new CancelEventHandler(ContextMenuItem_BeforePopup);
		}

		private void checkBox5_CheckedChanged(object sender, System.EventArgs e)
		{
			this.tabbedMDIManager.BeforeDropDownPopup += new DropDownPopupEventHandler(tabbedMDIManager_BeforePopup);
		}

		private void checkBox6_CheckedChanged(object sender, System.EventArgs e)
		{
			this.tabbedMDIManager.UseIconsInTabs = !this.tabbedMDIManager.UseIconsInTabs;
			this.Refresh();
		}

		private void checkBox7_CheckedChanged(object sender, System.EventArgs e)
		{
			this.tabbedMDIManager.Visible = !this.tabbedMDIManager.Visible;
		}

		private void checkBox8_CheckedChanged(object sender, System.EventArgs e)
		{
			this.tabbedMDIManager.CloseButtonVisible = !this.tabbedMDIManager.CloseButtonVisible;
		}

		#endregion

		# region Handlers
		private void parseChildren_Click(object sender, System.EventArgs e)
		{
			string children = String.Empty;
			// <samplecodeblock name="TabbedMDIManager: Getting the mdi children">
			foreach(Form form in this.tabbedMDIManager.MdiChildren)
			{
				children += form.Text + "\r\n";
			}
			//</samplecodeblock>
			MessageBox.Show(children);	
		}


		private void toggleAlign_Click(object sender, System.EventArgs e)
		{
			this.tabbedMDIManager.Horizontal = !this.tabbedMDIManager.Horizontal;
		}


		private void tabbedMDIManager_TabControlAdded(object sender, TabbedMDITabControlEventArgs args)
		{
			args.TabControl.ControlAdded += new ControlEventHandler(TabControl_ControlAdded);
			

			// Alignment
			if (this.menuItem18.Checked == true)
				args.TabControl.Alignment = TabAlignment.Top;
			else if (this.menuItem19.Checked == true)
				args.TabControl.Alignment = TabAlignment.Bottom;
			else if (this.menuItem20.Checked == true)
				args.TabControl.Alignment = TabAlignment.Left;
			else if (this.menuItem21.Checked == true)
				args.TabControl.Alignment = TabAlignment.Right;
		}

	
		private void ContextMenuItem_BeforePopup(object sender, CancelEventArgs e)
		{
			e.Cancel = this.checkBox4.Checked;
		}


		private void tabbedMDIManager_BeforePopup(object sender, DropDownPopupEventArgs e)
		{
			e.ParentBarItem.Style = Syncfusion.Windows.Forms.VisualStyle.Office2003;
			e.Cancel = this.checkBox5.Checked;
		}

		private void TabControl_ControlAdded(object sender, ControlEventArgs e)
		{
			if(e.Control is TabPageAdv)
			{
				TabPageAdv tabPage = e.Control as TabPageAdv;
				if(tabPage != null)
				{
//					if(this.menuItem10.Checked || this.menuItem11.Checked || this.menuItem12.Checked || this.menuItem13.Checked)
//					{
//						Random random = new Random();
//						tabPage.TabForeColor = Color.White;
//						tabPage.TabBackColor = Color.FromArgb(255, random.Next(0, 255), random.Next(0, 255), random.Next(0, 255));
//					}
				}
			}
		}
		#endregion

		private void checkBox3_CheckedChanged(object sender, System.EventArgs e)
		{
			this.tabbedMDIManager.CloseOnMiddleButtonClick = !this.tabbedMDIManager.CloseOnMiddleButtonClick ;
		}

	
	}
}


